# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class QueryDetails(object):
    """
    Input arguments for running a log anlaytics query. If the request is set to run in asynchronous mode
    then shouldIncludeColumns and shouldIncludeFields can be overwritten when retrieving the results.
    """

    #: A constant which can be used with the sub_system property of a QueryDetails.
    #: This constant has a value of "LOG"
    SUB_SYSTEM_LOG = "LOG"

    #: A constant which can be used with the async_mode property of a QueryDetails.
    #: This constant has a value of "FOREGROUND"
    ASYNC_MODE_FOREGROUND = "FOREGROUND"

    #: A constant which can be used with the async_mode property of a QueryDetails.
    #: This constant has a value of "BACKGROUND"
    ASYNC_MODE_BACKGROUND = "BACKGROUND"

    def __init__(self, **kwargs):
        """
        Initializes a new QueryDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this QueryDetails.
        :type compartment_id: str

        :param compartment_id_in_subtree:
            The value to assign to the compartment_id_in_subtree property of this QueryDetails.
        :type compartment_id_in_subtree: bool

        :param saved_search_id:
            The value to assign to the saved_search_id property of this QueryDetails.
        :type saved_search_id: str

        :param query_string:
            The value to assign to the query_string property of this QueryDetails.
        :type query_string: str

        :param sub_system:
            The value to assign to the sub_system property of this QueryDetails.
            Allowed values for this property are: "LOG"
        :type sub_system: str

        :param max_total_count:
            The value to assign to the max_total_count property of this QueryDetails.
        :type max_total_count: int

        :param time_filter:
            The value to assign to the time_filter property of this QueryDetails.
        :type time_filter: TimeRange

        :param scope_filters:
            The value to assign to the scope_filters property of this QueryDetails.
        :type scope_filters: list[ScopeFilter]

        :param query_timeout_in_seconds:
            The value to assign to the query_timeout_in_seconds property of this QueryDetails.
        :type query_timeout_in_seconds: int

        :param should_run_async:
            The value to assign to the should_run_async property of this QueryDetails.
        :type should_run_async: bool

        :param async_mode:
            The value to assign to the async_mode property of this QueryDetails.
            Allowed values for this property are: "FOREGROUND", "BACKGROUND"
        :type async_mode: str

        :param should_include_total_count:
            The value to assign to the should_include_total_count property of this QueryDetails.
        :type should_include_total_count: bool

        :param should_include_columns:
            The value to assign to the should_include_columns property of this QueryDetails.
        :type should_include_columns: bool

        :param should_include_fields:
            The value to assign to the should_include_fields property of this QueryDetails.
        :type should_include_fields: bool

        :param should_use_acceleration:
            The value to assign to the should_use_acceleration property of this QueryDetails.
        :type should_use_acceleration: bool

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'compartment_id_in_subtree': 'bool',
            'saved_search_id': 'str',
            'query_string': 'str',
            'sub_system': 'str',
            'max_total_count': 'int',
            'time_filter': 'TimeRange',
            'scope_filters': 'list[ScopeFilter]',
            'query_timeout_in_seconds': 'int',
            'should_run_async': 'bool',
            'async_mode': 'str',
            'should_include_total_count': 'bool',
            'should_include_columns': 'bool',
            'should_include_fields': 'bool',
            'should_use_acceleration': 'bool'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'compartment_id_in_subtree': 'compartmentIdInSubtree',
            'saved_search_id': 'savedSearchId',
            'query_string': 'queryString',
            'sub_system': 'subSystem',
            'max_total_count': 'maxTotalCount',
            'time_filter': 'timeFilter',
            'scope_filters': 'scopeFilters',
            'query_timeout_in_seconds': 'queryTimeoutInSeconds',
            'should_run_async': 'shouldRunAsync',
            'async_mode': 'asyncMode',
            'should_include_total_count': 'shouldIncludeTotalCount',
            'should_include_columns': 'shouldIncludeColumns',
            'should_include_fields': 'shouldIncludeFields',
            'should_use_acceleration': 'shouldUseAcceleration'
        }

        self._compartment_id = None
        self._compartment_id_in_subtree = None
        self._saved_search_id = None
        self._query_string = None
        self._sub_system = None
        self._max_total_count = None
        self._time_filter = None
        self._scope_filters = None
        self._query_timeout_in_seconds = None
        self._should_run_async = None
        self._async_mode = None
        self._should_include_total_count = None
        self._should_include_columns = None
        self._should_include_fields = None
        self._should_use_acceleration = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this QueryDetails.
        Compartment Identifier `OCID]`__.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this QueryDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this QueryDetails.
        Compartment Identifier `OCID]`__.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this QueryDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def compartment_id_in_subtree(self):
        """
        Gets the compartment_id_in_subtree of this QueryDetails.
        Flag to search all child compartments of the compartment Id specified in the compartmentId query parameter.


        :return: The compartment_id_in_subtree of this QueryDetails.
        :rtype: bool
        """
        return self._compartment_id_in_subtree

    @compartment_id_in_subtree.setter
    def compartment_id_in_subtree(self, compartment_id_in_subtree):
        """
        Sets the compartment_id_in_subtree of this QueryDetails.
        Flag to search all child compartments of the compartment Id specified in the compartmentId query parameter.


        :param compartment_id_in_subtree: The compartment_id_in_subtree of this QueryDetails.
        :type: bool
        """
        self._compartment_id_in_subtree = compartment_id_in_subtree

    @property
    def saved_search_id(self):
        """
        Gets the saved_search_id of this QueryDetails.
        Saved search OCID for this query if known, used to track usage of saved search queryString.


        :return: The saved_search_id of this QueryDetails.
        :rtype: str
        """
        return self._saved_search_id

    @saved_search_id.setter
    def saved_search_id(self, saved_search_id):
        """
        Sets the saved_search_id of this QueryDetails.
        Saved search OCID for this query if known, used to track usage of saved search queryString.


        :param saved_search_id: The saved_search_id of this QueryDetails.
        :type: str
        """
        self._saved_search_id = saved_search_id

    @property
    def query_string(self):
        """
        **[Required]** Gets the query_string of this QueryDetails.
        Query to perform.


        :return: The query_string of this QueryDetails.
        :rtype: str
        """
        return self._query_string

    @query_string.setter
    def query_string(self, query_string):
        """
        Sets the query_string of this QueryDetails.
        Query to perform.


        :param query_string: The query_string of this QueryDetails.
        :type: str
        """
        self._query_string = query_string

    @property
    def sub_system(self):
        """
        **[Required]** Gets the sub_system of this QueryDetails.
        Default subsystem to qualify fields with in the queryString if not specified.

        Allowed values for this property are: "LOG"


        :return: The sub_system of this QueryDetails.
        :rtype: str
        """
        return self._sub_system

    @sub_system.setter
    def sub_system(self, sub_system):
        """
        Sets the sub_system of this QueryDetails.
        Default subsystem to qualify fields with in the queryString if not specified.


        :param sub_system: The sub_system of this QueryDetails.
        :type: str
        """
        allowed_values = ["LOG"]
        if not value_allowed_none_or_none_sentinel(sub_system, allowed_values):
            raise ValueError(
                "Invalid value for `sub_system`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._sub_system = sub_system

    @property
    def max_total_count(self):
        """
        Gets the max_total_count of this QueryDetails.
        Maximum number of results to count.  Note a maximum of 2001 will be enforced; that is, actualMaxTotalCountUsed = Math.min(maxTotalCount, 2001).


        :return: The max_total_count of this QueryDetails.
        :rtype: int
        """
        return self._max_total_count

    @max_total_count.setter
    def max_total_count(self, max_total_count):
        """
        Sets the max_total_count of this QueryDetails.
        Maximum number of results to count.  Note a maximum of 2001 will be enforced; that is, actualMaxTotalCountUsed = Math.min(maxTotalCount, 2001).


        :param max_total_count: The max_total_count of this QueryDetails.
        :type: int
        """
        self._max_total_count = max_total_count

    @property
    def time_filter(self):
        """
        Gets the time_filter of this QueryDetails.

        :return: The time_filter of this QueryDetails.
        :rtype: TimeRange
        """
        return self._time_filter

    @time_filter.setter
    def time_filter(self, time_filter):
        """
        Sets the time_filter of this QueryDetails.

        :param time_filter: The time_filter of this QueryDetails.
        :type: TimeRange
        """
        self._time_filter = time_filter

    @property
    def scope_filters(self):
        """
        Gets the scope_filters of this QueryDetails.
        List of filters to be applied when the query executes. More than one filter per field is not permitted.


        :return: The scope_filters of this QueryDetails.
        :rtype: list[ScopeFilter]
        """
        return self._scope_filters

    @scope_filters.setter
    def scope_filters(self, scope_filters):
        """
        Sets the scope_filters of this QueryDetails.
        List of filters to be applied when the query executes. More than one filter per field is not permitted.


        :param scope_filters: The scope_filters of this QueryDetails.
        :type: list[ScopeFilter]
        """
        self._scope_filters = scope_filters

    @property
    def query_timeout_in_seconds(self):
        """
        Gets the query_timeout_in_seconds of this QueryDetails.
        Amount of time, in seconds, allowed for a query to execute. If this time expires before the query is complete, any partial results will be returned.


        :return: The query_timeout_in_seconds of this QueryDetails.
        :rtype: int
        """
        return self._query_timeout_in_seconds

    @query_timeout_in_seconds.setter
    def query_timeout_in_seconds(self, query_timeout_in_seconds):
        """
        Sets the query_timeout_in_seconds of this QueryDetails.
        Amount of time, in seconds, allowed for a query to execute. If this time expires before the query is complete, any partial results will be returned.


        :param query_timeout_in_seconds: The query_timeout_in_seconds of this QueryDetails.
        :type: int
        """
        self._query_timeout_in_seconds = query_timeout_in_seconds

    @property
    def should_run_async(self):
        """
        Gets the should_run_async of this QueryDetails.
        Option to run the query asynchronously. This will lead to a LogAnalyticsQueryJobWorkRequest being submitted and the {workRequestId} will be returned to fetch the results.


        :return: The should_run_async of this QueryDetails.
        :rtype: bool
        """
        return self._should_run_async

    @should_run_async.setter
    def should_run_async(self, should_run_async):
        """
        Sets the should_run_async of this QueryDetails.
        Option to run the query asynchronously. This will lead to a LogAnalyticsQueryJobWorkRequest being submitted and the {workRequestId} will be returned to fetch the results.


        :param should_run_async: The should_run_async of this QueryDetails.
        :type: bool
        """
        self._should_run_async = should_run_async

    @property
    def async_mode(self):
        """
        Gets the async_mode of this QueryDetails.
        Execution mode for the query if running asynchronously  (shouldRunAsync is true).

        Allowed values for this property are: "FOREGROUND", "BACKGROUND"


        :return: The async_mode of this QueryDetails.
        :rtype: str
        """
        return self._async_mode

    @async_mode.setter
    def async_mode(self, async_mode):
        """
        Sets the async_mode of this QueryDetails.
        Execution mode for the query if running asynchronously  (shouldRunAsync is true).


        :param async_mode: The async_mode of this QueryDetails.
        :type: str
        """
        allowed_values = ["FOREGROUND", "BACKGROUND"]
        if not value_allowed_none_or_none_sentinel(async_mode, allowed_values):
            raise ValueError(
                "Invalid value for `async_mode`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._async_mode = async_mode

    @property
    def should_include_total_count(self):
        """
        Gets the should_include_total_count of this QueryDetails.
        Include the total number of results from the query. Note, this value will always be equal to or less than maxTotalCount.


        :return: The should_include_total_count of this QueryDetails.
        :rtype: bool
        """
        return self._should_include_total_count

    @should_include_total_count.setter
    def should_include_total_count(self, should_include_total_count):
        """
        Sets the should_include_total_count of this QueryDetails.
        Include the total number of results from the query. Note, this value will always be equal to or less than maxTotalCount.


        :param should_include_total_count: The should_include_total_count of this QueryDetails.
        :type: bool
        """
        self._should_include_total_count = should_include_total_count

    @property
    def should_include_columns(self):
        """
        Gets the should_include_columns of this QueryDetails.
        Include columns in response


        :return: The should_include_columns of this QueryDetails.
        :rtype: bool
        """
        return self._should_include_columns

    @should_include_columns.setter
    def should_include_columns(self, should_include_columns):
        """
        Sets the should_include_columns of this QueryDetails.
        Include columns in response


        :param should_include_columns: The should_include_columns of this QueryDetails.
        :type: bool
        """
        self._should_include_columns = should_include_columns

    @property
    def should_include_fields(self):
        """
        Gets the should_include_fields of this QueryDetails.
        Include fields in response


        :return: The should_include_fields of this QueryDetails.
        :rtype: bool
        """
        return self._should_include_fields

    @should_include_fields.setter
    def should_include_fields(self, should_include_fields):
        """
        Sets the should_include_fields of this QueryDetails.
        Include fields in response


        :param should_include_fields: The should_include_fields of this QueryDetails.
        :type: bool
        """
        self._should_include_fields = should_include_fields

    @property
    def should_use_acceleration(self):
        """
        Gets the should_use_acceleration of this QueryDetails.
        Controls if query should ignore pre-calculated results if available and only use raw data.


        :return: The should_use_acceleration of this QueryDetails.
        :rtype: bool
        """
        return self._should_use_acceleration

    @should_use_acceleration.setter
    def should_use_acceleration(self, should_use_acceleration):
        """
        Sets the should_use_acceleration of this QueryDetails.
        Controls if query should ignore pre-calculated results if available and only use raw data.


        :param should_use_acceleration: The should_use_acceleration of this QueryDetails.
        :type: bool
        """
        self._should_use_acceleration = should_use_acceleration

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import


from .db_backups_client import DbBackupsClient
from .db_backups_client_composite_operations import DbBackupsClientCompositeOperations
from .db_system_client import DbSystemClient
from .db_system_client_composite_operations import DbSystemClientCompositeOperations
from .mysqlaas_client import MysqlaasClient
from .mysqlaas_client_composite_operations import MysqlaasClientCompositeOperations
from .work_requests_client import WorkRequestsClient
from .work_requests_client_composite_operations import WorkRequestsClientCompositeOperations
from . import models

__all__ = ["DbBackupsClient", "DbBackupsClientCompositeOperations", "DbSystemClient", "DbSystemClientCompositeOperations", "MysqlaasClient", "MysqlaasClientCompositeOperations", "WorkRequestsClient", "WorkRequestsClientCompositeOperations", "models"]



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateAutoScalingConfigurationDetails(object):
    """
    UpdateAutoScalingConfigurationDetails model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateAutoScalingConfigurationDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateAutoScalingConfigurationDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this UpdateAutoScalingConfigurationDetails.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateAutoScalingConfigurationDetails.
        :type freeform_tags: dict(str, str)

        :param is_enabled:
            The value to assign to the is_enabled property of this UpdateAutoScalingConfigurationDetails.
        :type is_enabled: bool

        :param cool_down_in_seconds:
            The value to assign to the cool_down_in_seconds property of this UpdateAutoScalingConfigurationDetails.
        :type cool_down_in_seconds: int

        """
        self.swagger_types = {
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'is_enabled': 'bool',
            'cool_down_in_seconds': 'int'
        }

        self.attribute_map = {
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'is_enabled': 'isEnabled',
            'cool_down_in_seconds': 'coolDownInSeconds'
        }

        self._defined_tags = None
        self._display_name = None
        self._freeform_tags = None
        self._is_enabled = None
        self._cool_down_in_seconds = None

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateAutoScalingConfigurationDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this UpdateAutoScalingConfigurationDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateAutoScalingConfigurationDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this UpdateAutoScalingConfigurationDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdateAutoScalingConfigurationDetails.
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.


        :return: The display_name of this UpdateAutoScalingConfigurationDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdateAutoScalingConfigurationDetails.
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.


        :param display_name: The display_name of this UpdateAutoScalingConfigurationDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateAutoScalingConfigurationDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this UpdateAutoScalingConfigurationDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateAutoScalingConfigurationDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this UpdateAutoScalingConfigurationDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def is_enabled(self):
        """
        Gets the is_enabled of this UpdateAutoScalingConfigurationDetails.
        Whether the autoscaling configuration is enabled.


        :return: The is_enabled of this UpdateAutoScalingConfigurationDetails.
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        """
        Sets the is_enabled of this UpdateAutoScalingConfigurationDetails.
        Whether the autoscaling configuration is enabled.


        :param is_enabled: The is_enabled of this UpdateAutoScalingConfigurationDetails.
        :type: bool
        """
        self._is_enabled = is_enabled

    @property
    def cool_down_in_seconds(self):
        """
        Gets the cool_down_in_seconds of this UpdateAutoScalingConfigurationDetails.
        The minimum period of time to wait between scaling actions. The cooldown period gives the system time
        to stabilize before rescaling. The minimum value is 300 seconds, which is also the default.


        :return: The cool_down_in_seconds of this UpdateAutoScalingConfigurationDetails.
        :rtype: int
        """
        return self._cool_down_in_seconds

    @cool_down_in_seconds.setter
    def cool_down_in_seconds(self, cool_down_in_seconds):
        """
        Sets the cool_down_in_seconds of this UpdateAutoScalingConfigurationDetails.
        The minimum period of time to wait between scaling actions. The cooldown period gives the system time
        to stabilize before rescaling. The minimum value is 300 seconds, which is also the default.


        :param cool_down_in_seconds: The cool_down_in_seconds of this UpdateAutoScalingConfigurationDetails.
        :type: int
        """
        self._cool_down_in_seconds = cool_down_in_seconds

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

import oci  # noqa: F401
from oci.util import WAIT_RESOURCE_NOT_FOUND  # noqa: F401


class ApplicationMigrationClientCompositeOperations(object):
    """
    This class provides a wrapper around :py:class:`~oci.application_migration.ApplicationMigrationClient` and offers convenience methods
    for operations that would otherwise need to be chained together. For example, instead of performing an action
    on a resource (e.g. launching an instance, creating a load balancer) and then using a waiter to wait for the resource
    to enter a given state, you can call a single method in this class to accomplish the same functionality
    """

    def __init__(self, client, **kwargs):
        """
        Creates a new ApplicationMigrationClientCompositeOperations object

        :param ApplicationMigrationClient client:
            The service client which will be wrapped by this object
        """
        self.client = client



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ReplicationPolicy(object):
    """
    The details of a replication policy.
    """

    #: A constant which can be used with the status property of a ReplicationPolicy.
    #: This constant has a value of "ACTIVE"
    STATUS_ACTIVE = "ACTIVE"

    #: A constant which can be used with the status property of a ReplicationPolicy.
    #: This constant has a value of "CLIENT_ERROR"
    STATUS_CLIENT_ERROR = "CLIENT_ERROR"

    def __init__(self, **kwargs):
        """
        Initializes a new ReplicationPolicy object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this ReplicationPolicy.
        :type id: str

        :param name:
            The value to assign to the name property of this ReplicationPolicy.
        :type name: str

        :param destination_region_name:
            The value to assign to the destination_region_name property of this ReplicationPolicy.
        :type destination_region_name: str

        :param destination_bucket_name:
            The value to assign to the destination_bucket_name property of this ReplicationPolicy.
        :type destination_bucket_name: str

        :param time_created:
            The value to assign to the time_created property of this ReplicationPolicy.
        :type time_created: datetime

        :param time_last_sync:
            The value to assign to the time_last_sync property of this ReplicationPolicy.
        :type time_last_sync: datetime

        :param status:
            The value to assign to the status property of this ReplicationPolicy.
            Allowed values for this property are: "ACTIVE", "CLIENT_ERROR", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param status_message:
            The value to assign to the status_message property of this ReplicationPolicy.
        :type status_message: str

        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'destination_region_name': 'str',
            'destination_bucket_name': 'str',
            'time_created': 'datetime',
            'time_last_sync': 'datetime',
            'status': 'str',
            'status_message': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'destination_region_name': 'destinationRegionName',
            'destination_bucket_name': 'destinationBucketName',
            'time_created': 'timeCreated',
            'time_last_sync': 'timeLastSync',
            'status': 'status',
            'status_message': 'statusMessage'
        }

        self._id = None
        self._name = None
        self._destination_region_name = None
        self._destination_bucket_name = None
        self._time_created = None
        self._time_last_sync = None
        self._status = None
        self._status_message = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this ReplicationPolicy.
        The id of the replication policy.


        :return: The id of this ReplicationPolicy.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ReplicationPolicy.
        The id of the replication policy.


        :param id: The id of this ReplicationPolicy.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this ReplicationPolicy.
        The name of the policy.


        :return: The name of this ReplicationPolicy.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ReplicationPolicy.
        The name of the policy.


        :param name: The name of this ReplicationPolicy.
        :type: str
        """
        self._name = name

    @property
    def destination_region_name(self):
        """
        **[Required]** Gets the destination_region_name of this ReplicationPolicy.
        The destination region to replicate to, for example \"us-ashburn-1\".


        :return: The destination_region_name of this ReplicationPolicy.
        :rtype: str
        """
        return self._destination_region_name

    @destination_region_name.setter
    def destination_region_name(self, destination_region_name):
        """
        Sets the destination_region_name of this ReplicationPolicy.
        The destination region to replicate to, for example \"us-ashburn-1\".


        :param destination_region_name: The destination_region_name of this ReplicationPolicy.
        :type: str
        """
        self._destination_region_name = destination_region_name

    @property
    def destination_bucket_name(self):
        """
        **[Required]** Gets the destination_bucket_name of this ReplicationPolicy.
        The bucket to replicate to in the destination region. Replication policy creation does not automatically
        create a destination bucket. Create the destination bucket before creating the policy.


        :return: The destination_bucket_name of this ReplicationPolicy.
        :rtype: str
        """
        return self._destination_bucket_name

    @destination_bucket_name.setter
    def destination_bucket_name(self, destination_bucket_name):
        """
        Sets the destination_bucket_name of this ReplicationPolicy.
        The bucket to replicate to in the destination region. Replication policy creation does not automatically
        create a destination bucket. Create the destination bucket before creating the policy.


        :param destination_bucket_name: The destination_bucket_name of this ReplicationPolicy.
        :type: str
        """
        self._destination_bucket_name = destination_bucket_name

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this ReplicationPolicy.
        The date when the replication policy was created as per `RFC 3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this ReplicationPolicy.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this ReplicationPolicy.
        The date when the replication policy was created as per `RFC 3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this ReplicationPolicy.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_last_sync(self):
        """
        **[Required]** Gets the time_last_sync of this ReplicationPolicy.
        Changes made to the source bucket before this time has been replicated.


        :return: The time_last_sync of this ReplicationPolicy.
        :rtype: datetime
        """
        return self._time_last_sync

    @time_last_sync.setter
    def time_last_sync(self, time_last_sync):
        """
        Sets the time_last_sync of this ReplicationPolicy.
        Changes made to the source bucket before this time has been replicated.


        :param time_last_sync: The time_last_sync of this ReplicationPolicy.
        :type: datetime
        """
        self._time_last_sync = time_last_sync

    @property
    def status(self):
        """
        **[Required]** Gets the status of this ReplicationPolicy.
        The replication status of the policy. If the status is CLIENT_ERROR, once the user fixes the issue
        described in the status message, the status will become ACTIVE.

        Allowed values for this property are: "ACTIVE", "CLIENT_ERROR", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this ReplicationPolicy.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this ReplicationPolicy.
        The replication status of the policy. If the status is CLIENT_ERROR, once the user fixes the issue
        described in the status message, the status will become ACTIVE.


        :param status: The status of this ReplicationPolicy.
        :type: str
        """
        allowed_values = ["ACTIVE", "CLIENT_ERROR"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    @property
    def status_message(self):
        """
        **[Required]** Gets the status_message of this ReplicationPolicy.
        A human-readable description of the status.


        :return: The status_message of this ReplicationPolicy.
        :rtype: str
        """
        return self._status_message

    @status_message.setter
    def status_message(self, status_message):
        """
        Sets the status_message of this ReplicationPolicy.
        A human-readable description of the status.


        :param status_message: The status_message of this ReplicationPolicy.
        :type: str
        """
        self._status_message = status_message

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
